@@ -6,7 +6,7 @@ use crate::cli::Cli;
 use crate::event_reader::EventReader;
 use crate::explorer;
 use crate::lua;
-use crate::pipe_reader;
+use crate::pipe;
 use crate::pwd_watcher;
 use crate::ui;
 use anyhow::{bail, Error, Result};
@@ -33,6 +33,22 @@ pub fn get_tty() -> Result<fs::File> {
     }
 }
 
+// In unix system, the std::env::current_dir() calls libc getcwd() that
+// returns physical path. As a workaround, this function tries to use `PWD`
+// environment variable that is configured by shell.
+fn get_current_dir() -> Result<PathBuf, std::io::Error> {
+    let cur = std::env::current_dir();
+    if let Ok(pwd) = std::env::var("PWD") {
+        if pwd.is_empty() {
+            cur
+        } else {
+            Ok(PathBuf::from(pwd))
+        }
+    } else {
+        cur
+    }
+}
+
 fn call_lua_heavy(
     app: &app::App,
     lua: &mlua::Lua,
@@ -110,25 +126,10 @@ pub struct Runner {
     extra_config_files: Vec<PathBuf>,
     on_load: Vec<app::ExternalMsg>,
     read_only: bool,
+    print_pwd_as_result: bool,
     selection: Vec<PathBuf>,
 }
 
-// In unix system, the std::env::current_dir() calls libc getcwd() that
-// returns physical path. As a workaround, this function tries to use `PWD`
-// environment variable that is configured by shell.
-fn get_current_dir() -> Result<PathBuf, std::io::Error> {
-    let cur = std::env::current_dir();
-    if let Ok(pwd) = std::env::var("PWD") {
-        if pwd.is_empty() {
-            cur
-        } else {
-            Ok(PathBuf::from(pwd))
-        }
-    } else {
-        cur
-    }
-}
-
 impl Runner {
     /// Create a new runner object passing the default arguments
     pub fn new() -> Result<Self> {
@@ -161,6 +162,7 @@ impl Runner {
             extra_config_files: cli.extra_config,
             on_load: cli.on_load,
             read_only: cli.read_only,
+            print_pwd_as_result: cli.print_pwd_as_result,
             selection: paths.collect(),
         })
     }
@@ -297,7 +299,12 @@ impl Runner {
                             }
 
                             PrintResultAndQuit => {
-                                result = Ok(Some(app.result_str()));
+                                result = if self.print_pwd_as_result {
+                                    Ok(Some(app.pwd_str()))
+                                } else {
+                                    Ok(Some(app.result_str()))
+                                };
+
                                 break 'outer;
                             }
 
@@ -479,7 +486,7 @@ impl Runner {
                                     })
                                     .unwrap_or_else(|e| Err(e.to_string()));
 
-                                match pipe_reader::read_all(&app.pipe.msg_in) {
+                                match pipe::read_all(&app.pipe.msg_in) {
                                     Ok(msgs) => {
                                         app = app
                                             .handle_batch_external_msgs(msgs)?;
@@ -716,7 +723,7 @@ impl Runner {
                                     .unwrap_or_else(|e| Err(e.to_string()));
 
                                 // TODO remove duplicate segment
-                                match pipe_reader::read_all(&app.pipe.msg_in) {
+                                match pipe::read_all(&app.pipe.msg_in) {
                                     Ok(msgs) => {
                                         app = app
                                             .handle_batch_external_msgs(msgs)?;
